@@ -1,15 +1,13 @@
 package Dist::Inkt::Role::SignDistribution;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.015';
+our $VERSION   = '0.016';
 
 use Moose::Role;
 use Module::Signature ();
 use File::chdir;
 use namespace::autoclean;
 
-with 'Dist::Inkt::Role::RDFModel';
-
 after BUILD => sub {
 	my $self = shift;
 	unshift @{ $self->targets }, 'SIGNATURE';
@@ -23,7 +21,7 @@ sub Build_SIGNATURE
 	$self->log('Writing %s', $file);
 	$self->rights_for_generated_files->{'SIGNATURE'} ||= [
 		'None', 'public-domain'
-	] if $self->DOES('Dist::Inkt::Role::WriteCOPYRIGHT');
+	];
 	$file->spew('placeholder');
 }
 
